contactos library

Classes

Contact
A model representing a contact.
Contact$Field
Contact$Field class used for contact fields which only have a label and a value, such as emails and phone numbers
Contact$PostalAddress
A model representing a postal address.
Contactos
The iOS implementation of ContactosPlatform.

Enums

FormOperationErrorCode
Error codes for form operations

Exceptions / Errors

FormOperationException
Exception thrown when a form operation fails