FormOperationErrorCode enum

Error codes for form operations

Inheritance
Available extensions

Values

canceled → const FormOperationErrorCode

The form operation was canceled

couldNotBeOpen → const FormOperationErrorCode

The form operation could not be open

unknown → const FormOperationErrorCode

An unknown error occurred

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FormOperationErrorCode>
A constant List of the values in this enum, in order of their declaration.