Contact$Field class
Contact$Field class used for contact fields which only have a label and a value, such as emails and phone numbers
- Annotations
Constructors
- Contact$Field({String? label, String? value})
-
Contact$Field class used for contact fields which only have a label and
a value, such as emails and phone numbers
const
- Contact$Field.fromJson(JSON json)
-
Creates an Contact$Field from a
Map<String, Object?>. Contact$Field class used for contact fields which only have a label and a value, such as emails and phone numbersfactory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- label → String?
-
The label of the item (e.g., "home", "work")
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
The value of the item (e.g., an email address, phone number)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override