Contact$PostalAddress class
A model representing a postal address.
- Annotations
Constructors
- Contact$PostalAddress({String? label, String? street, String? city, String? postcode, String? region, String? country})
-
A model representing a postal address.
const
- Contact$PostalAddress.fromJson(JSON json)
-
Creates a Contact$PostalAddress from a
Map<String, Object?>. A model representing a postal address.factory
Properties
- city → String?
-
The city of the postal address
final
- country → String?
-
The country of the postal address
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- label → String?
-
The label of the postal address (e.g., "home", "work")
final
- postcode → String?
-
The postal code of the postal address
final
- region → String?
-
The region or state of the postal address
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- street → String?
-
The street name and number of the postal address
final
Methods
-
copyWith(
{String? label, String? street, String? city, String? postcode, String? region, String? country}) → Contact$PostalAddress - Creates a copy of this postal address
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override