Contactos class
The iOS implementation of ContactosPlatform.
This class implements the package:contactos functionality for iOS.
- Inheritance
-
- Object
- PlatformInterface
- Contactos
Properties
- channel → MethodChannelContactos
-
Underlying channel-based implementation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMock → bool
-
Only mock implementations should set this to true.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addContact(
Contact c) → Future< void> -
Adds the
contactto the device contact list -
delegateFor(
{required MethodChannelContactos channel}) → ContactosPlatform - Enables delegates to create new instances of themselves if a none default.
-
deleteContact(
Contact c) → Future< void> -
Deletes the
contactif it has a valid identifier -
getAvatar(
Contact contact, {bool photoHighRes = true}) → Future< Uint8List?> -
Loads the avatar for the given contact and returns it. If the user does
not have an avatar, then
nullis returned in that slot. Only implemented on Android. -
getContacts(
{String? query, bool withThumbnails = true, bool photoHighResolution = true, bool orderByGivenName = true, bool iOSLocalizedLabels = true, bool androidLocalizedLabels = true}) → Future< List< Contact> > -
Fetches all contacts, or when specified, the contacts with a name
matching
query -
getContactsForEmail(
String email, {bool withThumbnails = true, bool photoHighResolution = true, bool orderByGivenName = true, bool iOSLocalizedLabels = true, bool androidLocalizedLabels = true}) → Future< List< Contact> > -
Fetches all contacts, or when specified, the contacts with the email
matching
emailWorks only on iOS -
getContactsForPhone(
String? phone, {bool withThumbnails = true, bool photoHighResolution = true, bool orderByGivenName = true, bool iOSLocalizedLabels = true, bool androidLocalizedLabels = true}) → Future< List< Contact> > -
Fetches all contacts, or when specified, the contacts with the phone
matching
phone -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openContactForm(
{bool iOSLocalizedLabels = true, bool androidLocalizedLabels = true}) → Future< Contact> - Opens the contact form with the fields prefilled with the values from the
-
openDeviceContactPicker(
{bool iOSLocalizedLabels = true, bool androidLocalizedLabels = true}) → Future< Contact?> - Displays the device/native contact picker dialog and returns the contact selected by the user
-
openExistingContact(
Contact contact, {bool iOSLocalizedLabels = true, bool androidLocalizedLabels = true}) → Future< Contact> -
Opens the contact form with the fields prefilled with the values from the
contactparameter -
toString(
) → String -
A string representation of this object.
inherited
-
updateContact(
Contact c) → Future< void> -
Updates the
contactif it has a valid identifier
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Static Methods
-
registerWith(
) → void - Registers this class as the default instance of Contactos.