FormOperationException class
Exception thrown when a form operation fails
Constructors
- FormOperationException({FormOperationErrorCode? errorCode})
-
Exception thrown when a form operation fails
const
- FormOperationException.canceled()
-
Creates a FormOperationException
with a FormOperationErrorCode.canceled
Exception thrown when a form operation fails
constfactory
- FormOperationException.couldNotBeOpen()
-
Creates a FormOperationException
with a FormOperationErrorCode.couldNotBeOpen
Exception thrown when a form operation fails
constfactory
- FormOperationException.unknown()
-
Creates a FormOperationException
with a FormOperationErrorCode.unknown
Exception thrown when a form operation fails
constfactory
Properties
- errorCode → FormOperationErrorCode?
-
The error code associated with this exception
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited